@@ -32,6 +32,7 @@ from .bigoven import BigOven
 from .blueapron import BlueApron
 from .bodybuilding import Bodybuilding
 from .bonappetit import BonAppetit
+from .bongeats import BongEats
 from .bowlofdelicious import BowlOfDelicious
 from .briceletbaklava import BricelEtBaklava
 from .budgetbytes import BudgetBytes
@@ -82,10 +83,13 @@ from .franzoesischkochen import FranzoesischKochen
 from .fredriksfikaallas import FredriksFikaAllas
 from .g750g import G750g
 from .geniuskitchen import GeniusKitchen
+from .gesundaktiv import GesundAktiv
 from .giallozafferano import GialloZafferano
 from .gimmesomeoven import GimmeSomeOven
 from .globo import Globo
+from .godt import Godt
 from .gonnawantseconds import GonnaWantSeconds
+from .goodfooddiscoveries import GoodFoodDiscoveries
 from .goustojson import GoustoJson
 from .greatbritishchefs import GreatBritishChefs
 from .halfbakedharvest import HalfBakedHarvest
@@ -147,6 +151,7 @@ from .mykitchen101 import MyKitchen101
 from .mykitchen101en import MyKitchen101en
 from .myrecipes import MyRecipes
 from .nhshealthierfamilies import NHSHealthierFamilies
+from .nibbledish import NibbleDish
 from .nihhealthyeating import NIHHealthyEating
 from .nourishedbynutrition import NourishedByNutrition
 from .nutritionbynathalie import NutritionByNathalie
@@ -158,6 +163,7 @@ from .owenhan import OwenHan
 from .paleorunningmomma import PaleoRunningMomma
 from .panelinha import Panelinha
 from .paninihappy import PaniniHappy
+from .pickuplimes import PickUpLimes
 from .pingodoce import PingoDoce
 from .popsugar import PopSugar
 from .practicalselfreliance import PracticalSelfReliance
@@ -171,6 +177,7 @@ from .rachlmansfield import RachlMansfield
 from .rainbowplantlife import RainbowPlantLife
 from .realfoodtesco import RealFoodTesco
 from .realsimple import RealSimple
+from .reciperunner import RecipeRunner
 from .recipetineats import RecipeTinEats
 from .redhousespice import RedHouseSpice
 from .reishunger import Reishunger
@@ -178,6 +185,7 @@ from .rezeptwelt import Rezeptwelt
 from .rosannapansino import RosannaPansino
 from .rutgerbakt import RutgerBakt
 from .sallysbakingaddiction import SallysBakingAddiction
+from .sallysblog import SallysBlog
 from .saveur import Saveur
 from .seriouseats import SeriousEats
 from .simpleveganista import SimpleVeganista
@@ -187,6 +195,7 @@ from .simplyrecipes import SimplyRecipes
 from .simplywhisked import SimplyWhisked
 from .skinnytaste import SkinnyTaste
 from .smulweb import Smulweb
+from .sobors import SoBors
 from .southerncastiron import SouthernCastIron
 from .southernliving import SouthernLiving
 from .spendwithpennies import SpendWithPennies
@@ -204,6 +213,7 @@ from .tastesoflizzyt import TastesOfLizzyT
 from .tasty import Tasty
 from .tastykitchen import TastyKitchen
 from .theclevercarrot import TheCleverCarrot
+from .theexpertguides import TheExpertGuides
 from .thehappyfoodie import TheHappyFoodie
 from .thekitchenmagpie import TheKitchenMagPie
 from .thekitchn import TheKitchn
@@ -216,6 +226,7 @@ from .timesofindia import TimesOfIndia
 from .tineno import TineNo
 from .tudogostoso import TudoGostoso
 from .twopeasandtheirpod import TwoPeasAndTheirPod
+from .usapears import USAPears
 from .usdamyplate import USDAMyPlate
 from .valdemarsro import Valdemarsro
 from .vanillaandbean import VanillaAndBean
@@ -262,6 +273,7 @@ SCRAPERS = {
     Bodybuilding.host(): Bodybuilding,
     BonAppetit.host(): BonAppetit,
     BowlOfDelicious.host(): BowlOfDelicious,
+    BongEats.host(): BongEats,
     BricelEtBaklava.host(): BricelEtBaklava,
     BudgetBytes.host(): BudgetBytes,
     CastIronKeto.host(): CastIronKeto,
@@ -315,7 +327,9 @@ SCRAPERS = {
     GialloZafferano.host(): GialloZafferano,
     GimmeSomeOven.host(): GimmeSomeOven,
     Globo.host(): Globo,
+    Godt.host(): Godt,
     GonnaWantSeconds.host(): GonnaWantSeconds,
+    GoodFoodDiscoveries.host(): GoodFoodDiscoveries,
     GoustoJson.host(): GoustoJson,
     GreatBritishChefs.host(): GreatBritishChefs,
     HEB.host(): HEB,
@@ -325,11 +339,23 @@ SCRAPERS = {
     HeadbangersKitchen.host(): HeadbangersKitchen,
     HeinzBrasil.host(): HeinzBrasil,
     HelloFresh.host(): HelloFresh,
+    HelloFresh.host(domain="at"): HelloFresh,
+    HelloFresh.host(domain="be"): HelloFresh,
+    HelloFresh.host(domain="ca"): HelloFresh,
+    HelloFresh.host(domain="ch"): HelloFresh,
+    HelloFresh.host(domain="co.nz"): HelloFresh,
     HelloFresh.host(domain="co.uk"): HelloFresh,
+    HelloFresh.host(domain="com.au"): HelloFresh,
     HelloFresh.host(domain="de"): HelloFresh,
+    HelloFresh.host(domain="dk"): HelloFresh,
+    HelloFresh.host(domain="es"): HelloFresh,
     HelloFresh.host(domain="fr"): HelloFresh,
-    HelloFresh.host(domain="nl"): HelloFresh,
     HelloFresh.host(domain="ie"): HelloFresh,
+    HelloFresh.host(domain="it"): HelloFresh,
+    HelloFresh.host(domain="lu"): HelloFresh,
+    HelloFresh.host(domain="nl"): HelloFresh,
+    HelloFresh.host(domain="no"): HelloFresh,
+    HelloFresh.host(domain="se"): HelloFresh,
     HomeChef.host(): HomeChef,
     Hostthetoast.host(): Hostthetoast,
     HundredAndOneCookbooks.host(): HundredAndOneCookbooks,
@@ -389,6 +415,7 @@ SCRAPERS = {
     MyKitchen101.host(): MyKitchen101,
     MyKitchen101en.host(): MyKitchen101en,
     MyRecipes.host(): MyRecipes,
+    NibbleDish.host(): NibbleDish,
     NHSHealthierFamilies.host(): NHSHealthierFamilies,
     NIHHealthyEating.host(): NIHHealthyEating,
     NYTimes.host(): NYTimes,
@@ -401,6 +428,7 @@ SCRAPERS = {
     PaleoRunningMomma.host(): PaleoRunningMomma,
     Panelinha.host(): Panelinha,
     PaniniHappy.host(): PaniniHappy,
+    PickUpLimes.host(): PickUpLimes,
     PingoDoce.host(): PingoDoce,
     PopSugar.host(): PopSugar,
     PracticalSelfReliance.host(): PracticalSelfReliance,
@@ -416,6 +444,7 @@ SCRAPERS = {
     RealFoodTesco.host(): RealFoodTesco,
     RealSimple.host(): RealSimple,
     RealFoodTesco.host(): RealFoodTesco,
+    RecipeRunner.host(): RecipeRunner,
     RecipeTinEats.host(): RecipeTinEats,
     RedHouseSpice.host(): RedHouseSpice,
     Reishunger.host(): Reishunger,
@@ -423,6 +452,7 @@ SCRAPERS = {
     RosannaPansino.host(): RosannaPansino,
     RutgerBakt.host(): RutgerBakt,
     SallysBakingAddiction.host(): SallysBakingAddiction,
+    SallysBlog.host(): SallysBlog,
     Saveur.host(): Saveur,
     SeriousEats.host(): SeriousEats,
     SimpleVeganista.host(): SimpleVeganista,
@@ -432,6 +462,7 @@ SCRAPERS = {
     SimplyWhisked.host(): SimplyWhisked,
     SkinnyTaste.host(): SkinnyTaste,
     Smulweb.host(): Smulweb,
+    SoBors.host(): SoBors,
     SouthernCastIron.host(): SouthernCastIron,
     SouthernLiving.host(): SouthernLiving,
     SpendWithPennies.host(): SpendWithPennies,
@@ -449,6 +480,7 @@ SCRAPERS = {
     Tasty.host(): Tasty,
     TastyKitchen.host(): TastyKitchen,
     TheCleverCarrot.host(): TheCleverCarrot,
+    TheExpertGuides.host(): TheExpertGuides,
     TheHappyFoodie.host(): TheHappyFoodie,
     TheKitchenMagPie.host(): TheKitchenMagPie,
     TheKitchn.host(): TheKitchn,
@@ -461,6 +493,7 @@ SCRAPERS = {
     TineNo.host(): TineNo,
     TudoGostoso.host(): TudoGostoso,
     TwoPeasAndTheirPod.host(): TwoPeasAndTheirPod,
+    USAPears.host(): USAPears,
     USDAMyPlate.host(): USDAMyPlate,
     Valdemarsro.host(): Valdemarsro,
     VanillaAndBean.host(): VanillaAndBean,
@@ -479,6 +512,7 @@ SCRAPERS = {
     Yummly.host(): Yummly,
     ZeitWochenmarkt.host(): ZeitWochenmarkt,
     ZenBelly.host(): ZenBelly,
+    GesundAktiv.host(): GesundAktiv,
 }
 
 
